"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var markRegExp_1 = __importDefault(require("./markRegExp"));
var markTerm_1 = __importDefault(require("./markTerm"));
/**
 * Replaces matching patterns in a string with markers.
 *
 * @param {string | React.ReactNodeArray} content The content to parse and mark.
 *
 * @param {string | RegExp} rule The pattern to search and replace in the
 * content.
 *
 * @param {Function} tag A function that takes the match string and must return
 * a React element. The value returned by that function will
 * replace the term in the output.
 *
 * @param {number} matchIndex The index of the match to use when marking with
 * a RegExp. If not provided, will use the last non-null match available.
 *
 * @returns {React.ReactNodeArray} A ReactNodeArray of strings and components,
 * similar to the original content but where each matching pattern has been
 * replaced by a marking component.
 */
function mark(content, rule, tag, matchIndex) {
    var _a;
    if (!Array.isArray(content)) {
        content = [content];
    }
    if (!(rule instanceof RegExp || typeof rule === 'string')) {
        throw Error('Unsupported rule type for rule `' + rule + '`.');
    }
    var output = [];
    for (var _i = 0, content_1 = content; _i < content_1.length; _i++) {
        var part = content_1[_i];
        if (typeof part === 'string') {
            var marked = void 0;
            if (rule instanceof RegExp) {
                marked = (0, markRegExp_1.default)(part, rule, tag, matchIndex);
            }
            else {
                marked = (0, markTerm_1.default)(part, rule, tag);
            }
            output.push(marked);
        }
        else {
            output.push(part);
        }
    }
    return (_a = []).concat.apply(_a, output);
}
exports.default = mark;
